//
//  Copyright (C) 2017 DB Systel GmbH.
//  DB Systel GmbH; Jürgen-Ponto-Platz 1; D-60329 Frankfurt am Main; Germany; http://www.dbsystel.de/
//
//  Permission is hereby granted, free of charge, to any person obtaining a 
//  copy of this software and associated documentation files (the "Software"), 
//  to deal in the Software without restriction, including without limitation 
//  the rights to use, copy, modify, merge, publish, distribute, sublicense, 
//  and/or sell copies of the Software, and to permit persons to whom the 
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in 
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
//  DEALINGS IN THE SOFTWARE.
//

import Foundation
import XCTest
@testable import DBNetworkStack

class DecodableResoureTest: XCTestCase {
    var resource: Resource<Train> {
        let url: URL! = URL(string: "bahn.de")
        let request = URLRequest(path: "/train", baseURL: url)
        return Resource<Train>(request: request, decoder: JSONDecoder())
    }
    
    func testResource_withValidData() {
        //When
        let fetchedTrain = try? resource.parse(Train.validJSONData)
        
        //Then
        XCTAssertEqual(fetchedTrain?.name, "ICE")
    }
    
    func testResource_withMAppedResult() {
        //When
        let nameResource = resource.map { $0.name }
        let fetchedTrainName = try? nameResource.parse(Train.validJSONData)
        
        //Then
        XCTAssertEqual(fetchedTrainName, "ICE")
    }
    
    func testResource_WithInvalidData() throws {
        //When
        do {
            _ = try resource.parse(Train.invalidJSONData)
            XCTFail("Expected method to throws")
        } catch { }
    }
    
}
